/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.cosmos.internal.dr.drs.service.handler.widget;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.HashMap;
import java.util.Map;

import org.eclipse.cosmos.provisional.dr.ps.common.IIDResolver;
import org.eclipse.cosmos.provisional.dr.ps.common.IOutputter;
import org.eclipse.cosmos.provisional.dr.ps.common.IParameters;
import org.eclipse.cosmos.provisional.dr.ps.common.IStore;
import org.eclipse.cosmos.provisional.dr.ps.common.MapParameterImpl;

public class WidgetPropertiesOutputter implements IOutputter {

	public static final String TAG="tag";
	public static final String DATAMAPFILE="datamap.jprop";
	public static final String VIEWFILE="view.jprop";
	protected String rootDir = "";
	public WidgetPropertiesOutputter(String rootDir){
		this.rootDir = rootDir;
	}
	public void initalize(Map parameters, IStore store) throws Exception {
		// TODO Auto-generated method stub

	}

	public void render(PrintWriter writer, IParameters input) throws Exception {
		String tag = input.getParameter(TAG);
		if (tag != null){
			writer.write("{view:");
			readPropertyFile(tag, VIEWFILE, writer);
			writer.write(",");
			writer.write("dataMap:");
			readPropertyFile(tag, DATAMAPFILE, writer);		
			writer.write("}");
		}
		else{
			//write empty object
			writer.write("{}");
		}
	}
	
	protected String generateFilename(String tag, String filename){
		//split tag name
		String tags[] =tag.split(" ");
		String newFileName = rootDir+File.separator;
		for (int x = 0; x < tags.length; x++){
			newFileName += tags[x]+File.separator;
		}
		return newFileName+filename;
	}
	protected void readPropertyFile(String tag, String filename, Writer writer)
			throws Exception {
		generateFilename(tag, filename);
		FileInputStream fis = null;
		ByteArrayOutputStream bos = null;

		try {
			String genFilename = generateFilename(tag, filename);
			File fileExists = new File(genFilename);
			if (fileExists.exists() && fileExists.isFile()){
				fis = new FileInputStream(generateFilename(tag, filename));
				bos = new ByteArrayOutputStream();
	
				int c;
	
				while ((c = fis.read()) != -1)
					writer.write(c);
			}
		} finally {

			if (fis != null)
				fis.close();

			if (bos != null)
				bos.close();
		}
	}

	public void setIdResolver(IIDResolver idResolver) {
		// TODO Auto-generated method stub

	}
	
	public static final void main(String[] argv) throws Exception{
		IOutputter out = new WidgetPropertiesOutputter("");
		Map input = new HashMap();
		input.put(WidgetPropertiesOutputter.TAG, "nav");
		PrintWriter pw = new PrintWriter(System.out);
		out.render(pw, new MapParameterImpl(input));
		pw.flush();
		pw.close();
	}

}
